/*
  AnyPrinter: dynamic print Any Value, use DynAny parsing.
  (part of realization of UA_KIEV_GRAD::Debug::AnyPrinter)

  (C) Ruslan Shevchenko <Ruslan@Shevchenko.Kiev.UA>, 1998
  AnyPrinter.cc,v 1.1 2004/03/05 17:12:50 stack Exp
*/

#include "config.h"

#include <iostream>

#include <BrokerC.h>
#include <Typecode.h>

#include <AnyPrinter.hh>

using namespace std;

extern CORBA::ORB* myORB;

void AnyPrinter::print_to_stream(ostream& os, const CORBA::Any& value)
{
    CORBA::TypeCode_var tc;

    tc = value.type();
    if (tc.in() == NULL) {
	cerr << "Illegal ANY" << endl;
	throw CORBA::BAD_TYPECODE();
	return;
    }
    switch(tc->kind()){
    case CORBA::tk_null:
	os << "null-typed" << endl;
	break;
    case CORBA::tk_void:
	os << "void" << endl;
	break;
    case CORBA::tk_short:
	{
	    CORBA::Short sh;
	    value >>= sh;
	    os << sh<<endl;
	}
	break;
    case CORBA::tk_long:
	{
	    CORBA::Long l;
	    value >>= l;
	    os << l << endl;
	}
	break;
    case CORBA::tk_ushort:
	{
	    CORBA::UShort ush;
	    value >>= ush;
	    os << ush << endl;
	}
	break;
    case CORBA::tk_ulong:
	{
	    CORBA::ULong ul;
	    value >>= ul;
	    os << ul << endl;
	}
	break;
    case CORBA::tk_float:
	{
	    CORBA::Float fl;
	    value >>= fl;
	    os << fl << endl;
	}
	break;
    case CORBA::tk_double:
	{
	    CORBA::Double d;
	    value >>= d;
	    os << "double:" << d << endl;
	}
	break;
    case CORBA::tk_boolean:
	{
	    CORBA::Boolean b;
	    value >>= CORBA::Any::to_boolean(b);
	    os << "boolean:" << (int)b << endl;
	}
	break;
    case CORBA::tk_char:
	{
	    CORBA::Char ch;
	    value >>= CORBA::Any::to_char(ch);
	    os << "char:" << ch << endl;
	}
	break;
    case CORBA::tk_octet:
	{ CORBA::Octet oc;
	value >>= CORBA::Any::to_octet(oc);
	os << "octet:" << oc << endl;
	}
	break;
    default:
	os << "unknown type" << endl;
	break;
    }
}
