#! /bin/sh

BROKER_ALLUP="${top_builddir}/allup/src/broker_allup -ORBEndpoint iiop://localhost:0"
CBHEY=${top_builddir}/cbhey/src/cbhey

$BROKER_ALLUP &
ALLUP_PID="$!"

trap 'kill $ALLUP_PID' EXIT

sleep 2

##

run_test $CBHEY -l

grep_output_for "IDL:Broker/Manager:1.0" \
    "Unable to list supported interfaces?"

##

run_test $CBHEY -l

grep_output_for "IDL:Broker/RealTimeTask:1.0" \
    "Unable to list supported interfaces (2)?"

##

$CBHEY file://allup.ior create library with name ${top_builddir}/libbroker/src/.libs/libcpu-broker > cb.ior

##

run_test $CBHEY file://allup.ior list libraries

grep_output_for "${top_builddir}/libbroker/src/.libs/libcpu-broker" \
    "Unable to list libraries?"

##

$CBHEY file://cb.ior create manager with name dummy > manager.ior
$CBHEY file://cb.ior create stub-real-time-task with name dummy > srtt.ior

##

run_test $CBHEY file://manager.ior list

check_output "Unable to list root properties?" <<EOF
policy
add-task
tasks
task
EOF

##

run_test $CBHEY file://manager.ior list foo

check_output "Able to list unknown property?" <<EOF
Unknown property: foo
EOF

##

run_test $CBHEY file://manager.ior get policy

check_output "Unable to get known property?" <<EOF
(none)
EOF

##

run_test $CBHEY file://manager.ior get foo

check_output "Able to get unknown property?" <<EOF
Unknown property: foo
EOF

##

run_test $CBHEY file://manager.ior get

check_output "Able to 'get' the root property?" <<EOF
Parse error: No more properties
EOF

##

run_test $CBHEY file://manager.ior set

check_output "Able to 'set' the root property?" <<EOF
Parse error: Missing 'to' keyword.
EOF

##

run_test $CBHEY file://manager.ior set policy to file://manager.ior

check_output "Able to 'set policy' to an incompatible object?" <<EOF
Caught Exception: BAD_PARAM (IDL:omg.org/CORBA/BAD_PARAM:1.0)
EOF

##

run_test $CBHEY file://manager.ior getsuites

check_output "Unable to get the root suites?" <<EOF
Property:  policy
  Supported verbs: get set
Get or set the object that implements the contention policy.  Policy objects
can be created using the libpolicies library.

Property:  add-task
  Supported verbs: execute
task:ior - The task to add.
pid:pid_t - The process ID to begin scheduling for.
period:time - The period for the reservation.
deadline:time - The deadline for the reservation.
... - Any additional key/value parameters.

Add a task to the manager.  Tasks must be added to the manager before
they can send a CPU usage report.

Property:  tasks
  Supported verbs: list
List the tasks currently being managed.

Property:  task
  Supported verbs: get
  Specifiers:  name:string - The task name.
Get the IOR for the task matching the given name.

EOF

##

run_test $CBHEY file://manager.ior execute add-task with task file://srtt.ior period 1s

check_output "Unable to add task srtt?" <<EOF
ok
EOF

##

run_test $CBHEY file://manager.ior list tasks

check_output "Unable to list tasks?" <<EOF
dummy
EOF

##

run_test $CBHEY file://manager.ior execute remove of task file://srtt.ior

check_output "Unable to remove task srtt?" <<EOF
ok
EOF

##

run_test $CBHEY file://manager.ior list tasks

check_output "Unable to list tasks (2)?" <<EOF
EOF

##
