/*
 * basic_kernel.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file basic_kernel.cc
 *
 * Server for a Basic QuOKernel.
 */

#include "config.h"

#include <fstream>
#include <iostream>

#include "BasicTaskKernelImpl.h"

using namespace std;

int main(int argc, char *argv[])
{
    ACE_DEBUG ((LM_DEBUG, ACE_TEXT(" quokernel-cpp started up \n")));
    
    // initialize ORB
    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
    
    // Get access to RootPOA
    CORBA::Object_var poaobj = orb->resolve_initial_references ("RootPOA");
    PortableServer::POA_var poa = PortableServer::POA::_narrow(poaobj.in());
    
    // Activate the POAManager
    poa->the_POAManager()->activate();
    
    // instantiate corba object & register it
    Qosket::Basic::BasicTaskKernelImpl kernel_serv (CORBA::ORB::_duplicate(orb.in()));
    quo::QuoKernel_ptr kernel = kernel_serv._this();
    
    // write IOR to file
    ofstream ostr("quoKernel.ior");
    ostr << orb->object_to_string(kernel) << endl;
    ostr.close();
    
    // we're done
    ACE_DEBUG((LM_ERROR, ACE_TEXT("quokernel is ready \n") ));
    orb->run();
    
    // exit gracefully
#ifdef QUO_USE_TAO
    orb->shutdown();
#endif
    
    return 0;
}
