#! /bin/sh

BROKER_ALLUP="${top_builddir}/allup/src/broker_allup -ORBEndpoint iiop://localhost:0"
CBHEY=${top_builddir}/cbhey/src/cbhey

$BROKER_ALLUP -f -p allup.pid > allup.out 2>&1

trap 'kill `cat allup.pid`' EXIT

sleep 2

$CBHEY file://allup.ior create library with name ${top_builddir}/libbroker/src/.libs/libcpu-broker > cb.ior
$CBHEY file://allup.ior create library with name ${top_builddir}/task_factories/src/.libs/libtask_factories > task_factories.ior

$CBHEY file://cb.ior create manager with name dummy > manager.ior
$CBHEY file://cb.ior create stub-real-time-task with name srtt > srtt.ior
$CBHEY file://cb.ior create stub-policy with name sp > sp.ior

$CBHEY file://manager.ior set policy to file://sp.ior > /dev/null

$CBHEY file://task_factories.ior create min-max-task-advocate with name mmta > mmta.ior
$CBHEY file://task_factories.ior create logging-advocate > la.ior
$CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://mmta.ior set remote-object to file://la.ior > /dev/null
$CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://la.ior set remote-object to file://srtt.ior > /dev/null

##

run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://mmta.ior set manager to file://manager.ior

check_output "Unable to set the manager?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://mmta.ior \
    set minimum to 500

check_output "Unable to set the minimum?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://mmta.ior \
    get minimum

check_output "Unable to get the minimum?" <<EOF
500
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://mmta.ior \
    set maximum to 1000

check_output "Unable to set the maximum?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://mmta.ior \
    get maximum

check_output "Unable to get the maximum?" <<EOF
1000
EOF

##

run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://mmta.ior execute report-cpu with status.period 100000 status.compute 0 advice.period 100000 advice.compute 0

check_output "Unable to report CPU usage?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://la.ior get last-advice

check_output "Unable to get new compute time?" <<EOF
500
EOF

##

run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://mmta.ior execute report-cpu with status.period 100000 status.compute 2000 advice.period 100000 advice.compute 2000

check_output "Unable to report CPU usage (2)?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://la.ior get last-advice

check_output "Unable to get new compute time (2)?" <<EOF
1000
EOF

##

run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://mmta.ior execute report-cpu with status.period 100000 status.compute 750 advice.period 100000 advice.compute 750

check_output "Unable to report CPU usage (3)?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://la.ior get last-advice

check_output "Unable to get new compute time (3)?" <<EOF
750
EOF

##
